import requests


def giveme(names: [str], system: str='macOS', target: str='./.gitignore'):
    """
    Parameters
    ----------
    names: a list of names. if more than one, concat ignore files
    """
    url = 'https://raw.githubusercontent.com/github/gitignore/master/{}.gitignore'
    content = b''
    for name in names:
        _content = requests.get(url.format(name.capitalize()))
        content += _content.content

    if system:
        _content = requests.get('https://raw.githubusercontent.com/github/gitignore/master/Global/{}.gitignore'.format(system))
        content += b'\n'
        content += _content.content

    with open(target, 'wb') as f:
        f.write(content)


if __name__ == '__main__':

    giveme(['Python'])


import click

from giveme.gitignore import giveme as git_giveme

table = {
    'git': git_giveme
}


@click.group()
def cli():
    pass


@cli.command()
@click.option('--name', '-n', multiple=True)
@click.option('--system', '-s', default='macOS', help='macOs, Windows, Linux')
@click.option('--target', '-t', default='./.gitignore')
def git(name: list, system: str, target):
    git_giveme(name, system=system, target=target)


if __name__ == '__main__':

    cli()


from setuptools import setup, find_packages

setup(
    name='givemestuff',
    version='0.4',
    author="Zhe Wang",
    author_email="wangzhetju@gmail.com",
    description="Giveme info",
    packages=find_packages(exclude=("tests",)),
    install_requires=[
        'Click',
        'requires'
    ],
    entry_points='''
        [console_scripts]
        giveme=giveme.main:cli
    ''',
)